package Tweet::ToDelicious::Entity::Interface;

use v5.14;
use warnings;

sub text                    {...}
sub screen_name             {...}
sub urls                    {...}
sub tags                    {...}
sub posts                   {...}
sub in_reply_to_screen_name {...}

1;
